@@ -3,8 +3,10 @@
 import os
 import re
 import subprocess
+import platform
 
 XMT_PATTERN = re.compile('\\s*file_name\\s*=\\s*"?.+\\.xmt_txt"?\\s*')
+LOG_FILE_ERROR_PATTERN = '! \\S*Error: '
 
 def get_simdur_from_msg(msg_file):
 	"""Reads an Adams message file (.msg) and returns the total duration of the simulation.
@@ -150,21 +152,59 @@ def solve(acf_file, wait=False, use_adams_car=False):
 
 	"""	
 	file = os.path.split(acf_file)[-1]
-	
-	if use_adams_car is False:
-		command = '"{}" ru-s "{}"'.format(os.environ['ADAMS_LAUNCH_COMMAND'], file)
-	else:
-		command = '"{}" acar ru-solver "{}"'.format(os.environ['ADAMS_LAUNCH_COMMAND'], file)
-		
-	startupinfo = subprocess.STARTUPINFO()
-	startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
 	cwd = os.path.dirname(acf_file) if os.path.dirname(acf_file) != '' else os.getcwd()
-	proc = subprocess.Popen(command, cwd=cwd, startupinfo=startupinfo)
+	
+	if platform.system() == 'Windows':
+		startupinfo = subprocess.STARTUPINFO()
+		startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+
+		if use_adams_car is False:
+			command = '"{}" ru-s "{}"'.format(os.environ['ADAMS_LAUNCH_COMMAND'], file)
+		else:
+			command = '"{}" acar ru-solver "{}"'.format(os.environ['ADAMS_LAUNCH_COMMAND'], file)
+		
+		proc = subprocess.Popen(command, cwd=cwd, startupinfo=startupinfo)
+	
+	else:
+		if use_adams_car is False:
+			command = [os.environ['ADAMS_LAUNCH_COMMAND'], '-c', 'ru-standard', 'i', file, 'exit']
+		else:
+			command = [os.environ['ADAMS_LAUNCH_COMMAND'], '-c', 'acar', 'ru-solver', 'i', file, 'exit']
+		
+		proc = subprocess.Popen(command, cwd=cwd)
 
 	if wait:
 		proc.wait()
 	
 	return proc
 
+def get_log_errors(log_file):
+	"""Checks the log file for errors of the type AviewError.
+	
+	Parameters
+	----------
+	log_file : str
+		Filename of aview log file (usulally aview.log)
+
+	"""
+	with open(log_file, 'r') as fid:
+		lines = fid.readlines()
+
+	errors = []
+	for line in lines:
+		if re.search(LOG_FILE_ERROR_PATTERN, line):
+			errors.append(line[2:])
+
+	if errors:
+		raise AviewError('\n'.join(errors))
+
+
 class AdmFileError(Exception):
 	pass
+
+
+class AviewError(Exception):
+	"""Raise this error to if a known error occurs in the log file.
+	
+	"""
+	pass
\ No newline at end of file
